# Response

A single response from an update.

**Type:** object

## Properties

- **replaceAllText** ([ReplaceAllTextResponse](replacealltextresponse.md)): The result of replacing text.
- **createNamedRange** ([CreateNamedRangeResponse](createnamedrangeresponse.md)): The result of creating a named range.
- **insertInlineImage** ([InsertInlineImageResponse](insertinlineimageresponse.md)): The result of inserting an inline image.
- **insertInlineSheetsChart** ([InsertInlineSheetsChartResponse](insertinlinesheetschartresponse.md)): The result of inserting an inline Google Sheets chart.
- **createHeader** ([CreateHeaderResponse](createheaderresponse.md)): The result of creating a header.
- **createFooter** ([CreateFooterResponse](createfooterresponse.md)): The result of creating a footer.
- **createFootnote** ([CreateFootnoteResponse](createfootnoteresponse.md)): The result of creating a footnote.
- **addDocumentTab** ([AddDocumentTabResponse](adddocumenttabresponse.md)): The result of adding a document tab.
